C
C *** READ OF SOIL DATA FROM DATA FILE
C
      SUBROUTINE SOILIN(DNS,G0,DAMP,DEP,NL,ML,STF)
C
C ** DNS(I) : DENSITY OF Ith LAYER
C ** VS (I) : VS OF Ith LAYER
C ** G0 (I) : SHEAR MODULUS OF Ith LAYER
C ** DEP(I) : DEPTH ( THICKNESS ) OF Ith LAYER
C ** DAMP(I): DAMPING FACTOR
C ** NL     : TOTAL NUMBER OF LAYERS
C ** ML     : NL IN MAIN PROGRAM DIMENSION
C ** STF(I) : Soil type factor(clay=0.0,sand=1.0)
C ** SU(I)  : Shear strength (t/m**2)
C
      DIMENSION DNS(ML),DEP(ML),G0(ML),DAMP(ML),STF(ML)
C
C *** SOIL DATA INPUT ***
C
      READ(3,1030)NL
      DO 100 IL=1,NL
      READ(3,1040) DNS(IL),G0(IL),DEP(IL),DAMP(IL),STF(IL)
  100 CONTINUE
 1010 FORMAT(F10.0)
 1030 FORMAT(I10)
 1040 FORMAT(5F10.0)
C
C *** DATA ECHO ***
C
      WRITE(6,2000)
      WRITE(6,2040)NL
      DO 200 IL=1,NL
      WRITE(6,2050)IL,DNS(IL),G0(IL),DEP(IL),DAMP(IL),STF(IL)
  200 CONTINUE
      WRITE(6,*)
 2000 FORMAT(/' FROM SUBROUTINE SOILIN : INPUT DATA ECHO')
 2040 FORMAT(' TOTAL RAYLERS NUMBER =',I5)
 2050 FORMAT(' IL,DNS,G0,DEP,H,STF=',I3,F6.3,2F10.3,F10.6,F6.3)
C
      RETURN
      END
